@@ -196,6 +196,8 @@ class PlotMap(MapCross, MapDrawOptions):
 
     def set_color_bar(self, mco, location='right', drawedges=False, cax=None):
         """ Create color bar """
+        if not location:
+            return
         mpl.rcParams['axes.linewidth'] = 0.1
         mpl.rcParams['axes.formatter.useoffset'] = False
         if self.ticks:
@@ -203,25 +205,39 @@ class PlotMap(MapCross, MapDrawOptions):
             self.ticks = parse_parameters_list(self.ticks)
         elif self.bounds:
             self.ticks = self.bounds
+            while len(self.ticks) > 10:
+                self.ticks = self.ticks[0::2]
         elif hasattr(mco, 'levels'):
             self.ticks = mco.levels
 
         LOG.debug("***** Formats: %s *****", self.formats)
-        pad = {'bottom': 0.05, 'right': 0.02}
-        pad = pad.get(location, 0.02)
-        cax, kwargs = mpl.colorbar.make_axes(self.mgaxis,
-                                             location=location,
-                                             pad=pad,
-                                             shrink=0.9)
-        cbar = self.mgplot.colorbar(mco,
-                                    cax=cax,
-                                    ax=self.mgaxis,
-                                    ticks=self.ticks,
-                                    format=self.formats,
-                                    pad=.06,
-                                    extend=self.extend,
-                                    drawedges=drawedges,
-                                    **kwargs)
+        if self.subplot:
+            orientation = {
+                'right': 'vertical',
+                'bottom': 'horizontal',
+            }
+            cbar = self.mgplot.colorbar(mco,
+                                        ax=self.mgaxis,
+                                        ticks=self.ticks,
+                                        format=self.formats,
+                                        pad=.15,
+                                        drawedges=drawedges,
+                                        orientation=orientation[location])
+        else:
+            pad = {'bottom': 0.05, 'right': 0.02}
+            pad = pad.get(location, 0.02)
+            cax, kwargs = mpl.colorbar.make_axes(self.mgaxis,
+                                                location=location,
+                                                pad=pad,
+                                                shrink=0.9)
+            cbar = self.mgplot.colorbar(mco,
+                                        cax=cax,
+                                        ax=self.mgaxis,
+                                        ticks=self.ticks,
+                                        format=self.formats,
+                                        pad=.06,
+                                        drawedges=drawedges,
+                                        **kwargs)
         cbar.ax.tick_params(labelsize=float(self.coordsopts[1]))
         for lin in cbar.ax.yaxis.get_ticklines():
             lin.set_visible(False)
@@ -583,8 +599,8 @@ class PlotMap(MapCross, MapDrawOptions):
             )
 
             if self.draw_labels and bool(self.projection == 'PlateCarree'):
-                grl.xlabels_top = False
-                grl.ylabels_right = False
+                grl.top_labels = False
+                grl.right_labels = False
             if self.draw_labels:
                 grl.xlabel_style = {'size': float(self.coordsopts[1])}
                 grl.ylabel_style = grl.xlabel_style
@@ -860,8 +876,10 @@ class PlotMap(MapCross, MapDrawOptions):
             else:
                 self.mgaxis = plt.subplot(self.subplot[0],
                                           self.subplot[1],
-                                          self.subplot[3],
-                                          projection=self._crs)
+                                          self.subplot[2],
+                                          projection=self._crs,
+                                          sharex=True,
+                                          sharey=True,)
                 self.mgplot = plt.gcf()
 
             valid_tmp = dims[n_time]
